@@ -1,8 +1,8 @@
 /**************************************************************************/
 /*                                                                        */
-/* Copyright (c) 2001, 2006 NoMachine, http://www.nomachine.com/.         */
+/* Copyright (c) 2001, 2009 NoMachine, http://www.nomachine.com/.         */
 /*                                                                        */
-/* NXPROXY, NX protocol compression and NX extensions to this software    */
+/* NXCOMP, NX protocol compression and NX extensions to this software     */
 /* are copyright of NoMachine. Redistribution and use of the present      */
 /* software is allowed according to terms specified in the file LICENSE   */
 /* which comes in the source distribution.                                */
@@ -65,6 +65,8 @@ class ClientProxy : public Proxy
   virtual int handleLoad(T_load_type type);
   virtual int handleSave();
 
+  virtual int handleAsyncEvents();
+
   virtual int handleLoadFromProxy();
   virtual int handleSaveFromProxy();
 
